@@ -6,11 +6,22 @@ test_that("read_html correctly parses malformed document", {
 })
 
 test_that("parse_options errors when given an invalid option", {
-  expect_error(parse_options("INVALID"),
-    "`options` INVALID is not a valid option")
+  expect_error(parse_options("INVALID", xml_parse_options()),
+    "`options` 'INVALID' is not a valid option")
 
   expect_error(read_html("lego.html.bz2", options = "INVALID"),
-    "`options` INVALID is not a valid option")
+    "`options` 'INVALID' is not a valid option")
+
+  # Empty inputs returned as 0
+  expect_identical(0L, parse_options("", xml_parse_options()))
+  expect_identical(0L, parse_options(NULL, xml_parse_options()))
+
+  # Numerics returned as integers
+  expect_identical(12L, parse_options(12L, xml_parse_options()))
+  expect_identical(12L, parse_options(12, xml_parse_options()))
+
+  # Multiple inputs summed
+  expect_identical(3L, parse_options(c("RECOVER", "NOENT"), xml_parse_options()))
 })
 
 test_that("read_html properly passes parser arguments", {
@@ -18,12 +29,12 @@ test_that("read_html properly passes parser arguments", {
   skip_if_not(libxml2_version() >= "2.9.2")
 
   blanks <- read_html("cd_catalog.xml.bz2", options = c("RECOVER", "NOERROR"))
-  expect_equal(as_list(blanks)$body$catalog$cd[[1]],
+  expect_equal(as_list(blanks)$html$body$catalog$cd[[1]],
     "\r\n    ")
 
   no_blanks <- read_html("cd_catalog.xml.bz2", options = c("RECOVER", "NOERROR", "NOBLANKS"))
 
-  expect_equal(as_list(no_blanks)$body$catalog$cd[[1]],
+  expect_equal(as_list(no_blanks)$html$body$catalog$cd[[1]],
     list("Empire Burlesque"))
 })
 
